ThinSlicePtr

Struct ThinSlicePtr 

pub struct ThinSlicePtr<'a, T> { /* private fields */ }
Conceptually equivalent to &'a [T] but with length information cut out for performance reasons.

Because this type does not store the length of the slice, it is unable to do any sort of bounds checking. As such, only Self::get_unchecked() is available for indexing into the slice, where the user is responsible for checking the bounds.

When compiled in debug mode (#[cfg(debug_assertion)]), this type will store the length of the slice and perform bounds checking in Self::get_unchecked().

Example

let slice: &[u32] = &[2, 4, 8];
let thin_slice = ThinSlicePtr::from(slice);

assert_eq!(*unsafe { thin_slice.get_unchecked(0) }, 2);
assert_eq!(*unsafe { thin_slice.get_unchecked(1) }, 4);
assert_eq!(*unsafe { thin_slice.get_unchecked(2) }, 8);

Implementations

Source

impl<'a, T> ThinSlicePtr<'a, T>

pub unsafe fn get_unchecked(&self, index: usize) -> &'a T

Indexes the slice without performing bounds checks.

Safety

index must be in-bounds.

pub unsafe fn as_slice_unchecked(&self, len: usize) -> &'a [T]

Returns a slice without performing bounds checks.

Safety
  • There must be no mutable aliases for the lifetime 'a to the slice. to the slice.
  • len must be less than or equal to the length of the slice.
pub unsafe fn get(self, index: usize) -> &'a T

👎Deprecated since 0.18.0:

use get_unchecked() instead

Indexes the slice without performing bounds checks.

Safety

index must be in-bounds.

Source

impl<'a, T> ThinSlicePtr<'a, UnsafeCell<T>>

pub unsafe fn as_mut_slice_unchecked(&self, len: usize) -> &'a mut [T]

Returns a mutable reference of the slice

Safety
  • There must not be any aliases for the lifetime 'a to the slice.
  • len must be less than or equal to the length of the slice.
pub fn cast(&self) -> ThinSlicePtr<'a, T>

Returns a slice pointer to the underlying type T.